﻿using System;
using System.Threading.Tasks;
using System.Web;
using System.Web.Mvc;

using GamesStore.Entities;
using GamesStore.Web.Models.Account;

using Microsoft.AspNet.Identity.Owin;

namespace GamesStore.Web.Controllers
{
    public class AccountController : Controller
    {
        [HttpGet]
        public ActionResult Login(string returnUrl)
        {          
            return View(new LoginViewModel { ReturnUrl = returnUrl });
        }


        [HttpPost]
        public async Task<ActionResult> Login(LoginViewModel loginData)
        {
            if (ModelState.IsValid)
            {
                var manager = HttpContext.GetOwinContext().Get<ApplicationUserManager>();

                //var user = manager.Users.FirstOrDefault(u => u.UserName == loginData.UserName);
                //if (user != null)
                //{
                //    var identity = await manager.CreateIdentityAsync(user, DefaultAuthenticationTypes.ApplicationCookie);
                //    HttpContext.GetOwinContext().Authentication.SignIn(identity);
                //}

                var signInManager = new SignInManager<User, string>(manager, HttpContext.GetOwinContext().Authentication);
                await signInManager.PasswordSignInAsync(loginData.UserName, loginData.Password, loginData.RememberMe, false);

                if (!String.IsNullOrEmpty(loginData.ReturnUrl))
                {
                    return Redirect(loginData.ReturnUrl);
                }

                return RedirectToAction("Index", "Games");
            }

            return View(loginData);
        }

        
        public ActionResult Logout()
        {
            HttpContext.GetOwinContext().Authentication.SignOut();

            return RedirectToAction("Index", "Games");
        }


        public PartialViewResult LoginHeaderPartial()
        {
            if (User.Identity.IsAuthenticated)
            {
                return PartialView("_LoginHeaderAuthenticated");
            }

            return PartialView("_LoginHeaderNotAuthenticated");
        }
    }
}